pub package

JuneflowDocumentation

flutter_lints_module

This module is a module of the juneflow framework about the cupertino_icons package.

Quick Started

  1. if you don't have a juneflow project, please create a new juneflow project.
    1. Please enter the following command in the terminal.
      dart pub global activate juneflow_cli
      june create-app
      
    2. After that, press enter to select the default project.
    3. Please enter the name of the project you want to use (only lowercase letters and underscores are allowed).
    4. Please create the project by entering the package name.
  2. open terminal in the project root, enter the following command.
    june add flutter_lints_module
    

Description & Usage

It will add the cupertino_icons package to the project and add the necessary settings to the project.